# Effects of personalized music listening on post-stroke cognitive impairment: A randomized controlled trial
# Author: Alonso Quijano-Ruiz
# Email: alonso@laboratoriolide.org
# Version: June 23rd 2024

# ------------------------------------- #
# ---------- Data & Packages ---------- #
# ------------------------------------- #

# Load the necessary package
library(tidyverse)

# Set working directory
setwd("___")

# Read the CSV file into a data frame
data <- read.csv("music_psci_rct.csv")

# Display the structure of the data frame
glimpse(data) 

# Split the data into baseline and outcome datasets
baseline_data <- data[, 1:17]
outcome_data <- data[, c(1, 2, 18:ncol(data))]

# ---------------------------------------------- #
# ---------- Baseline analysis ----------------- #
# ---------- Table 1: Characteristics ---------- #
# ---------------------------------------------- #

# Age Analysis:

## Calculate mean, variance, standard error, and confidence intervals for age
baseline_data %>% 
  group_by(group) %>% 
  summarize(
    n = n(),                                 # Calculate the sample size
    mean = mean(age),                        # Calculate the mean age
    se = sqrt(var(age) / n)                  # Calculate the standard error of the mean
  ) %>%
  mutate(
    t_se = qt(0.975, n - 1) * se,            # Calculate the margin of error for 95% CI
    ci_l = mean - t_se,                      # Calculate the lower bound of the 95% CI
    ci_u = mean + t_se                       # Calculate the upper bound of the 95% CI
  ) %>%
  mutate(
    mean = round(mean, 2),                   # Round the mean to 2 decimal places
    t_se = round(t_se, 2)                    # Round the margin of error to 2 decimal places
  ) %>%
  select(group, mean, t_se)                  # Select relevant columns for display

## Perform two-sample t-test assuming unequal variances for age
baseline_data %>% 
  select(group, age) %>% 
  oneway.test(age ~ group, data = .)

# Categorical Variables Analysis:

## Prepare data for categorical variable analysis
baseline_long <- baseline_data %>% select(-c("age"))
baseline_long <- baseline_long %>% 
  pivot_longer(
    cols = 3:ncol(baseline_long),            # Select columns to pivot (from the 3rd to the last column)
    names_to = "variable",                   # Create new column for variable names
    values_to = "value"                      # Name the column containing the values
  )

## Calculate proportions for categorical variables
baseline_long %>% 
  count(group, variable, value) %>%          # Count occurrences for each group-variable-value combination
  group_by(group, variable) %>% 
  mutate(prop = n / sum(n)) %>%              # Calculate proportion within each group-variable combination
  filter(value %in% c("yes", "male")) %>%    # Filter for relevant values
  mutate(mean = round(prop, 2)) %>%          # Round proportions to 2 decimal places
  print(n = Inf)                             # Print all rows

## Perform Chi-Square tests for categorical variables
chisq.test(data$group, data$gender)
chisq.test(data$group, data$low_educ)
chisq.test(data$group, data$smoke)
chisq.test(data$group, data$hypertension)
chisq.test(data$group, data$diabetes)
chisq.test(data$group, data$atrial_fibr)
chisq.test(data$group, data$atrial_fibr)
chisq.test(data$group, data$hyperlipidemia)
chisq.test(data$group, data$lesion_mult)
chisq.test(data$group, data$frontal)
chisq.test(data$group, data$temporal)
chisq.test(data$group, data$parietal)
chisq.test(data$group, data$insula)
chisq.test(data$group, data$other)

# ------------------------------------- #
# ---------- Table 1: Scores ---------- #
# ------------------------------------- #

## Convert data from wide format to long format
outcome_long <- outcome_data %>% 
  pivot_longer(
    cols = 3:ncol(outcome_data),             # Select columns to pivot (from the 3rd to the last column)
    names_to = c("outcome", "period"),       # Create new columns for outcome and period
    values_to = "score",                     # Name the column containing the values
    names_sep = "_"                          # Separator used in the original column names
  )

## Calculate summary statistics (mean, variance, standard error, and confidence intervals)
## for each outcome, group, and period combination
one_t_test <- outcome_long %>% 
  group_by(outcome, group, period) %>% 
  summarize(
    n = n(),                                 # Calculate the sample size
    mean = mean(score),                      # Calculate the mean score
    var = var(score),                        # Calculate the variance of the scores
    se = sqrt(var / n)                       # Calculate the standard error of the mean
  ) %>%
  mutate(
    t_se = qt(0.975, n - 1) * se,            # Calculate the margin of error for 95% CI
    ci_u = mean + t_se,                      # Calculate the upper bound of the 95% CI
    ci_l = mean - t_se                       # Calculate the lower bound of the 95% CI
  ) %>%
  ungroup()                                  # Ungroup to remove groupings

## Display the summary statistics for specific outcomes at baseline (BL) period
one_t_test %>% 
  filter(outcome %in% c("moca", "hama", "hamd", "nihss", "bi", "zarit")) %>%
  filter(period == "BL") %>%
  mutate(
    mean = round(mean, 2),                   # Round the mean to 2 decimal places
    t_se = round(t_se, 2)                    # Round the margin of error to 2 decimal places
  ) %>%
  select(outcome, group, period, mean, t_se) # Select relevant columns for display

## Conduct two-sample t-tests assuming unequal variances for baseline (BL) scores between groups
data %>% select(group, moca_BL) %>% 
  oneway.test(moca_BL ~ group, data = .) # MoCA

data %>% select(group, hama_BL) %>% 
  oneway.test(hama_BL ~ group, data = .) # HAMA

data %>% select(group, hamd_BL) %>% 
  oneway.test(hamd_BL ~ group, data = .) # HAMD

data %>% select(group, nihss_BL) %>% 
  oneway.test(nihss_BL ~ group, data = .) # NIHSS

data %>% select(group, zarit_BL) %>% 
  oneway.test(zarit_BL ~ group, data = .) # Zarit Caregiver Burden

# ----------------------------- #
# ---------- Results ---------- #
# ----------------------------- #

# Conduct two-sample t-tests assuming unequal variance for each outcome and period
two_t_test <- one_t_test %>% 
  group_by(outcome, period) %>% 
  mutate(
    # Calculate the t-statistic for two-sample t-test
    t = (mean - lag(mean)) / sqrt((var / n) + (lag(var) / lag(n))),
    
    # Calculate the degrees of freedom for the t-test
    df = ((var / n) + (lag(var) / lag(n)))^2 / 
      (((var / n)^2 / (n - 1)) + ((lag(var) / lag(n))^2 / (lag(n) - 1))),
    
    # Calculate the two-tailed p-value from the t-statistic and degrees of freedom
    p_value = (1 - pt(abs(t), df = df)) * 2
  ) %>% 
  na.omit() %>%  # Remove rows with NA values (typically the first row in each group)
  select(outcome, period, t, p_value)  # Select relevant columns for display

# Print the t-statistic and p-value for all rows, rounding to 3 decimal places
two_t_test %>% 
  mutate(
    t = round(t, 3),         # Round the t-statistic to 3 decimal places
    p_value = round(p_value, 3)  # Round the p-value to 3 decimal places
  ) %>% 
  print(n = Inf)  # Print all rows of the resulting tibble

# -------------------------------------- #
# ---------- MoCA Improvement ---------- #
# -------------------------------------- #

# Calculate improvement in MoCA scores after three months of treatment
outcome_data$improv <- outcome_data$moca_3m - outcome_data$moca_BL

# Conduct a normality test on the MoCA improvement scores
shapiro.test(outcome_data$improv)

# Perform a one-sample t-test to summarize improvement statistics by group
outcome_data %>% 
  group_by(group) %>% 
  summarize(
    n = n(),                                # Calculate the sample size
    mean = mean(improv),                    # Calculate the mean improvement
    se = sqrt(var(improv) / n)              # Calculate the standard error of the mean
  ) %>%
  mutate(
    t_se = qt(0.975, n - 1) * se,           # Calculate the margin of error for 95% CI
    ci_l = mean - t_se,                     # Calculate the lower bound of the 95% CI
    ci_u = mean + t_se                      # Calculate the upper bound of the 95% CI
  ) %>%
  mutate(
    mean = round(mean, 2),                  # Round the mean to 2 decimal places
    t_se = round(t_se, 2)                   # Round the margin of error to 2 decimal places
  ) %>%
  select(group, mean, t_se)                 # Select relevant columns for display

# Conduct a two-sample t-test assuming independent variances
# Compare MoCA improvement scores between the music and control groups
t.test(
  outcome_data$improv[outcome_data$group == "music"], 
  outcome_data$improv[outcome_data$group == "control"]
)

# --------------------------- #
# ---------- Plots ---------- #
# --------------------------- #

# Figure 2: MoCA seven domains
one_t_test %>% 
  
  # Filter data to include only the MoCA seven domains
  filter(outcome %in% c("vis", "nam", "att", "lan", "abs", "rec", "ori")) %>%
  
  # Set the desired order and labels for the outcome variable using factor with levels
  mutate(
    outcome = factor(outcome, 
                     levels = c("vis", "nam", "att", "lan", "abs", "rec", "ori"),
                     labels = c("visuospatial and\nexecutive function", "naming",
                                "attention", "language", "abstraction", "delayed\nrecall*",
                                "orientation*"))
  ) %>%
  
  # Set the desired order for the period variable using factor with levels
  mutate(period = factor(period, levels = c("BL", "3m"))) %>%
  
  # Create the ggplot object
  ggplot(aes(x = period, y = mean, group = group, color = group)) + 
  
  # Add dashed lines for the groups with position dodge for better visibility
  geom_line(linetype = "dashed", position = position_dodge(width = 0.5)) +
  
  # Add error bars representing the confidence intervals
  geom_errorbar(aes(ymin = ci_l, ymax = ci_u), width = 0.2, position = position_dodge(width = 0.5)) + 
  
  # Create a faceted plot with free scales for each outcome, arrange in 4 columns
  facet_wrap(~outcome, scales = "free", ncol = 4) +
  
  # Customize the labels and theme of the plot
  labs(x = "", y = "") + 
  theme(
    panel.background = element_blank(),  # Remove panel background
    strip.background = element_blank(),  # Remove strip background
    legend.key = element_blank(),        # Remove legend key background
    legend.position = c(.875, .25),      # Position the legend
    axis.title.x = element_blank(),      # Remove x-axis title
    axis.title.y = element_blank(),      # Remove y-axis title
    axis.line = element_line(colour = "grey50")  # Customize axis lines
  )

# Figure 3: Secondary outcomes
one_t_test %>% 
  
  # Filter data to include only the specified outcomes
  filter(outcome %in% c("hama", "hamd", "nihss", "bi", "zarit")) %>%
  
  # Set the desired order and labels for the outcome variable using factor with levels
  mutate(
    outcome = factor(outcome, 
                     levels = c("hama", "hamd", "nihss", "bi", "zarit"),
                     labels = c("HAMA", "HAMD", "NIHSS**", "BI*", "ZBI**"))
  ) %>%
  
  # Set the desired order for the period variable using factor with levels
  mutate(period = factor(period, levels = c("BL", "3m"))) %>%
  
  # Create the ggplot object
  ggplot(aes(x = period, y = mean, group = group, color = group)) + 
  
  # Add dashed lines for the groups with position dodge for better visibility
  geom_line(linetype = "dashed", position = position_dodge(width = 0.5)) +
  
  # Add error bars representing the confidence intervals
  geom_errorbar(aes(ymin = ci_l, ymax = ci_u), width = 0.2, position = position_dodge(width = 0.5)) + 
  
  # Create a faceted plot with free scales for each outcome
  facet_wrap(~outcome, scales = "free") +
  
  # Customize the labels and theme of the plot
  labs(x = "", y = "") + 
  theme(
    panel.background = element_blank(),  # Remove panel background
    strip.background = element_blank(),  # Remove strip background
    legend.key = element_blank(),        # Remove legend key background
    legend.position = c(.85, .25),       # Position the legend
    axis.title.x = element_blank(),      # Remove x-axis title
    axis.title.y = element_blank(),      # Remove y-axis title
    axis.line = element_line(colour = "grey50")  # Customize axis lines
  )
